/***********************************************************************
ColorSafe 1.0 Beta - http://www.woven-media.com/

A Java 6 Swing application for color testing and conversions from RGB to
hexadecimal data formats and vice versa.

Copyright (C) 2008-2009, Brent Allen Parrish <info@woven-media.com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/
package com.woven_media.colorsafe;

import java.awt.Font;
import java.awt.Color;
import java.awt.Component;
import javax.swing.UIManager;
import javax.swing.SwingUtilities;

/**
 * ColorSafeUI class handles setting the overall LookAndFeel for
 * <code>ColorSafe 1.0</code>.
 *
 * @since 1.0
 */
public class ColorSafeUI
{
    private static Controller controller;

    /**
     * Sets this instance's <code>com.woven_media.app.colorsafe.Controller</code>
     * object.
     *
     * @param c <code>com.woven_media.app.colorsafe.Controller</code> instance.
     * @since   1.0
     */
    public static void setController(Controller c)
    {
       controller = c;
    }

    /**
     * Setups the pluggable look and feel (PLAF) via the <code>javax.swing.UIManager</code>.
     *
     * @see   javax.swing.UIManager
     * @since 1.0
     */
    public static void setUI()
    {
        // TODO: This belongs in its own class!

        Color bg = controller.getBgColor();
        //Color menuBarBg = new Color(99, 130, 191); // med.dark blue
        Color menuBarBg = new Color(200, 200, 200); // light gray
        Font font10 = new Font("Arial", Font.PLAIN, 10);
        Font font12 = new Font("Arial", Font.PLAIN, 12);
        UIManager.put("MenuBar.background", menuBarBg);
        UIManager.put("MenuBar.foreground", new Color(204, 204, 204)); // light gray
        UIManager.put("Menu.foreground", new Color(53, 53, 53));
        UIManager.put("MenuBar.shadow", menuBarBg);
        UIManager.put("MenuBar.highlight", menuBarBg);
        UIManager.put("Menu.selectionBackground", bg);
        UIManager.put("Menu.selectionForeground", new Color(51, 51, 51));
        UIManager.put("Menu.shadow", menuBarBg);
        UIManager.put("Menu.background", menuBarBg);
        UIManager.put("MenuItem.selectionBackground", menuBarBg);
        UIManager.put("ColorChooser.background", bg);
        UIManager.put("OptionPane.background", bg);
        UIManager.put("OptionPane.warningDialog.border.background", menuBarBg);
        UIManager.put("OptionPane.warningDialog.titlePane.background", bg);
        UIManager.put("OptionPane.Menubar.background", menuBarBg);
        UIManager.put("OptionPane.warningDialog.titlePane.foreground", menuBarBg);
        //UIManager.put("OptionPane.warningDialog.titlePane.shadow", bg);
        UIManager.put("RadioButton.background", bg);
        UIManager.put("TabbedPane.background", bg);
        UIManager.put("Panel.background", bg);
        UIManager.put("Slider.background", bg);
        UIManager.put("Label.background", bg);
        UIManager.put("ToolTip.background", new Color(255, 255, 204));
        UIManager.put("Button.font", font10);
        UIManager.put("Menu.font", font12);
        UIManager.put("MenuItem.font", font12);
        UIManager.put("RadioButtonMenuItem.font", font12);
        UIManager.put("CheckBox.background", bg);
        if(controller.getImageIcon() != null)
        {
            UIManager.put("OptionPane.warningIcon", controller.getImageIcon());
        }
    }

    /**
     * Updates the ComponentTreeUI when this LookAndFeel changes.
     *
     * @param c <code>java.awt.Component</code> that requires updating its component UI tree.
     * @see     javax.swing.SwingUtilities
     */
    public static void updateComponentUI(Component c)
    {
        SwingUtilities.updateComponentTreeUI(c);
    }

} // End class